@@ -2,7 +2,6 @@ package main
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -60,12 +59,12 @@ func resolvePuppetEnvironment(tags bool, outputNameTag string) {
 			if success := doMirrorOrUpdate(controlRepoGit, workDir, 0); success {
 
 				// get all branches
-				er := executeCommand("git --git-dir "+workDir+" branch", "", config.Timeout, false)
+				er := executeCommand("git --git-dir "+workDir+" branch", "", config.Timeout, false, false)
 				outputBranches := er.output
 				outputTags := ""
 
 				if tags {
-					er := executeCommand("git --git-dir "+workDir+" tag", "", config.Timeout, false)
+					er := executeCommand("git --git-dir "+workDir+" tag", "", config.Timeout, false, false)
 					outputTags = er.output
 				}
 
@@ -151,8 +150,8 @@ func resolvePuppetEnvironment(tags bool, outputNameTag string) {
 							}
 
 							mutex.Lock()
-							if _, ok := allEnvironments[prefix+renamedBranch]; !ok {
-								allEnvironments[prefix+renamedBranch] = true
+							if _, ok := allEnvironments[filepath.Join(sa.Basedir, prefix+renamedBranch)]; !ok {
+								allEnvironments[filepath.Join(sa.Basedir, prefix+renamedBranch)] = true
 							} else {
 								Fatalf("Renamed environment naming conflict detected with renamed environment " + prefix + renamedBranch)
 							}
@@ -317,10 +316,10 @@ func resolvePuppetfile(allPuppetfiles map[string]Puppetfile) {
 
 		for _, moduleDir := range pf.moduleDirs {
 			moduleDir = normalizeDir(filepath.Join(pf.workDir, moduleDir))
-			exisitingModuleDirsFI, _ := ioutil.ReadDir(moduleDir)
+			exisitingModuleDirsFI, _ := os.ReadDir(moduleDir)
 			mutex.Lock()
 			for _, exisitingModuleDir := range exisitingModuleDirsFI {
-				//fmt.Println("adding dir: ", moduleDir+exisitingModuleDir.Name())
+				// fmt.Println("adding dir: ", filepath.Join(moduleDir, exisitingModuleDir.Name()))
 				exisitingModuleDirs[filepath.Join(moduleDir, exisitingModuleDir.Name())] = empty
 			}
 			mutex.Unlock()
@@ -489,7 +488,7 @@ func skipBasedOnFilterCommand(branch string, sourceName string, sa Source, workD
 	branchFilterCommand = strings.ReplaceAll(branchFilterCommand, "$G10K_NAME", sourceName)
 	branchFilterCommand = strings.ReplaceAll(branchFilterCommand, "$GIT_DIR", workDir)
 	Debugf("executing filter_command: " + branchFilterCommand)
-	er := executeCommand(branchFilterCommand, "", 30, true)
+	er := executeCommand(branchFilterCommand, "", 30, true, false)
 	if debug {
 		fmt.Printf("filter_command %s result: %+v", branchFilterCommand, er)
 	}
